package com.ruoyi.web.yh.prodOrder.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.k3cloud.constants.fileds.K3ProdField;
import com.ruoyi.web.yh.material.service.MaterialService;
import com.ruoyi.web.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.web.yh.prodOrder.service.ProdOrderConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author wjh
 * 2024/10/30
 */
@Service
public class ProdOrderConverterImpl implements ProdOrderConverter {

    /**
     * 将ERP数据转为PO列表
     *
     * @param headers 表头列表
     * @param erpList ERP数据列表
     */
    @Override
    public List<ProdOrder> toPoByErpList(List<String> headers, List<JSONArray> erpList) {
        if (CollectionUtils.isEmpty(headers) || CollectionUtils.isEmpty(erpList)) {
            return Collections.emptyList();
        }

        // 创建erpList大小的对象列表
        List<ProdOrder> result = new ArrayList<>(erpList.size());

        LocalDateTime syncTime = LocalDateTime.now();

        for (JSONArray row : erpList) {
            ProdOrder po = new ProdOrder();
            for (int i = 0; i < headers.size(); i++) {
                String header = headers.get(i);
                switch(header) {
                    case K3ProdField.FID:
                        po.setErpId(row.getString(i));
                        break;
                    case K3ProdField.F_BILL_NO:
                        po.setErpBillNo(row.getString(i));
                        break;
                    case K3ProdField.F_DOCUMENT_STATUS:
                        po.setErpDocumentStatus(row.getString(i));
                        break;
                    case K3ProdField.F_CREATE_DATE:
                        po.setErpCreateDate(DateUtils.toLocalDateTime(row.getDate(i)));
                        break;
                    case K3ProdField.F_MODIFY_DATE:
                        po.setErpModifyDate(DateUtils.toLocalDateTime(row.getDate(i)));
                        break;
                    case K3ProdField.F_DESCRIPTION:
                        po.setErpDescription(row.getString(i));
                        break;
                    case K3ProdField.F_DATE:
                        po.setErpDate(DateUtils.toLocalDateTime(row.getDate(i)));
                        break;
                    case K3ProdField.F_IS_REWORK:
                        po.setErpIsRework(row.getBoolean(i));
                        break;
                    case K3ProdField.F_ROW_ID:
                        po.setErpRowId(row.getString(i));
                        break;
                    case K3ProdField.F_MEMO_ITEM:
                        po.setErpMemoItem(row.getString(i));
                        break;
                    case K3ProdField.F_CONVEY_DATE:
                        po.setErpConveyDate(DateUtils.toLocalDateTime(row.getDate(i)));
                        break;
                    case K3ProdField.F_STATUS:
                        po.setErpStatus(row.getString(i));
                        break;
                    case K3ProdField.F_WORK_SHOP_ID:
                        po.setErpWorkShopId(row.getString(i));
                        break;
                    case K3ProdField.F_REQ_SRC:
                        po.setErpReqSrc(row.getString(i));
                        break;
                    case K3ProdField.F_BASE_UNIT_QTY:
                        po.setErpBaseUnitQty(row.getBigDecimal(i));
                        break;
                    case K3ProdField.F_QTY:
                        po.setErpQty(row.getBigDecimal(i));
                        break;
                    case K3ProdField.F_UNIT_ID:
                        po.setErpUnitId(row.getString(i));
                        break;
                    case K3ProdField.F_BASE_UNIT_ID:
                        po.setErpBaseUnitId(row.getString(i));
                        break;
                    case K3ProdField.F_MATERIAL_ID:
                        po.setErpMaterialId(row.getString(i));
                        break;
                    case K3ProdField.F_NO_STOCK_IN_QTY:
                        po.setErpNoStockInQty(row.getBigDecimal(i));
                        break;
                    case K3ProdField.F_BASE_NO_STOCK_IN_QTY:
                        po.setErpBaseNoStockInQty(row.getBigDecimal(i));
                        break;
                    default: break;
                }
            }

            // 同步时间
            po.setSyncTime(syncTime);

            result.add(po);
        }

        return result;
    }
}
