package com.ruoyi.web.yh.report.domain;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.framework.web.domain.log.LogBizParam;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * 报表对象 bst_report
 *
 * @author ruoyi
 * @date 2024-10-18
 */
@Data
public class Report extends BaseEntity implements LogBizParam
{
    private static final long serialVersionUID = 1L;

    private Long reportId;

    @Excel(name = "部门ID")
    @ApiModelProperty("部门ID")
    @NotNull(message = "部门ID不能为空")
    private Long deptId;

    @Excel(name = "状态", readConverterExp = "1=未提交,2=待审核,3=已通过,4=已驳回")
    @ApiModelProperty("状态")
    private String status;

    @Excel(name = "创建人ID")
    @ApiModelProperty("创建人ID")
    private Long createId;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "审核时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("审核时间")
    private LocalDateTime verifyTime;

    @Excel(name = "审核人ID")
    @ApiModelProperty("审核人ID")
    private Long verifyId;

    @Excel(name = "审核人名称")
    @ApiModelProperty("审核人名称")
    private String verifyBy;

    @Excel(name = "审核意见")
    @ApiModelProperty("审核意见")
    private String verifyRemark;

    @Excel(name = "更新人ID")
    @ApiModelProperty("更新人ID")
    private Long updateId;

    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "报表日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("报表日期")
    @NotNull(message = "报表日期不能为空")
    private LocalDate reportDate;

    @Excel(name = "总金额", readConverterExp = "元=")
    @ApiModelProperty("总金额")
    @NotNull(message = "总金额不能为空")
    @Min(value = 0, message = "总金额必须大于0")
    private BigDecimal totalAmount;

    /**
     * 获取日志业务ID
     */
    @Override
    public Object logBizId() {
        return this.getReportId();
    }
}
