package com.ruoyi.web.yh.reportOrderProd.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.web.yh.reportOrderProd.service.ReportOrderProdAssembler;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.yh.reportOrderProd.domain.ReportOrderProd;
import com.ruoyi.web.yh.reportOrderProd.domain.ReportOrderProdVO;
import com.ruoyi.web.yh.reportOrderProd.domain.ReportOrderProdQuery;
import com.ruoyi.web.yh.reportOrderProd.service.ReportOrderProdService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单产量Controller
 *
 * @author ruoyi
 * @date 2024-11-19
 */
@RestController
@RequestMapping("/yh/reportOrderProd")
public class ReportOrderProdController extends BaseController
{
    @Autowired
    private ReportOrderProdService reportOrderProdService;

    @Autowired
    private ReportOrderProdAssembler reportOrderProdAssembler;

    /**
     * 查询订单产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:list')")
    @GetMapping("/list")
    public TableDataInfo list(ReportOrderProdQuery query)
    {
        startPage();
        startOrderBy();
        List<ReportOrderProdVO> list = reportOrderProdService.selectReportOrderProdList(query);
        reportOrderProdAssembler.assembleVerifyingBaseNum(list);
        return getDataTable(list);
    }

    /**
     * 导出订单产量列表
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:export')")
    @Log(title = "订单产量", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ReportOrderProdQuery query)
    {
        List<ReportOrderProdVO> list = reportOrderProdService.selectReportOrderProdList(query);
        ExcelUtil<ReportOrderProdVO> util = new ExcelUtil<ReportOrderProdVO>(ReportOrderProdVO.class);
        util.exportExcel(response, list, "订单产量数据");
    }

    /**
     * 获取订单产量详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(reportOrderProdService.selectReportOrderProdById(id));
    }

    /**
     * 新增订单产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:add')")
    @Log(title = "订单产量", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ReportOrderProd reportOrderProd)
    {
        return toAjax(reportOrderProdService.insertReportOrderProd(reportOrderProd));
    }

    /**
     * 修改订单产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:edit')")
    @Log(title = "订单产量", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ReportOrderProd reportOrderProd)
    {
        return toAjax(reportOrderProdService.updateReportOrderProd(reportOrderProd));
    }

    /**
     * 删除订单产量
     */
    @PreAuthorize("@ss.hasPermi('yh:reportOrderProd:remove')")
    @Log(title = "订单产量", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(reportOrderProdService.deleteReportOrderProdByIds(ids));
    }
}
