package com.ruoyi.web.yh.reportProd.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.web.yh.reportOrderProd.domain.ReportOrderProdVO;
import com.ruoyi.web.yh.reportProd.domain.bo.ReportProdBO;
import com.ruoyi.web.yh.reportUserProd.domain.bo.ReportUserProdBO;
import com.ruoyi.web.yh.reportUserProd.service.ReportUserProdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.web.yh.reportProd.mapper.ReportProdMapper;
import com.ruoyi.web.yh.reportProd.domain.ReportProd;
import com.ruoyi.web.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.web.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.web.yh.reportProd.service.ReportProdService;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 报表产量Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-31
 */
@Service
public class ReportProdServiceImpl implements ReportProdService
{
    @Autowired
    private ReportProdMapper reportProdMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private ReportUserProdService reportUserProdService;

    /**
     * 查询报表产量
     *
     * @param id 报表产量主键
     * @return 报表产量
     */
    @Override
    public ReportProdVO selectReportProdById(Long id)
    {
        return reportProdMapper.selectReportProdById(id);
    }

    /**
     * 查询报表产量列表
     *
     * @param reportProd 报表产量
     * @return 报表产量
     */
    @Override
    public List<ReportProdVO> selectReportProdList(ReportProdQuery reportProd)
    {
        return reportProdMapper.selectReportProdList(reportProd);
    }

    /**
     * 新增报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    @Override
    public int insertReportProd(ReportProd reportProd)
    {
        return reportProdMapper.insertReportProd(reportProd);
    }

    /**
     * 修改报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    @Override
    public int updateReportProd(ReportProd reportProd)
    {
        return reportProdMapper.updateReportProd(reportProd);
    }

    /**
     * 批量删除报表产量
     *
     * @param ids 需要删除的报表产量主键
     * @return 结果
     */
    @Override
    public int deleteReportProdByIds(Long[] ids)
    {
        return reportProdMapper.deleteReportProdByIds(ids);
    }

    /**
     * 删除报表产量信息
     *
     * @param id 报表产量主键
     * @return 结果
     */
    @Override
    public int deleteReportProdById(Long id)
    {
        return reportProdMapper.deleteReportProdById(id);
    }

    @Override
    public int batchInsert(List<? extends ReportProd> productList) {
        if (CollectionUtils.isEmptyElement(productList) ) {
            return 0;
        }
        return reportProdMapper.batchInsert(productList);
    }

    @Override
    public int batchUpdate(List<? extends ReportProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return reportProdMapper.batchUpdate(list);
    }

    @Override
    public List<ReportProdVO> selectByReportId(Long reportId) {
        if (reportId == null) {
            return Collections.emptyList();
        }
        ReportProdQuery query = new ReportProdQuery();
        query.setReportId(reportId);
        return reportProdMapper.selectReportProdList(query);
    }

    @Override
    public int batchLogicDel(List<ReportProdVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        List<Long> ids = list.stream().map(ReportProdVO::getId).filter(Objects::nonNull).collect(Collectors.toList());
        return reportProdMapper.batchLogicDel(ids);
    }
}
